Renga CLI and SDK for Python — Renga 0.1.0.dev20171123 documentation

Join us on GitHub

# Renga CLI and SDK for Python

A Python library for the Renga collaborative data science platform. It allows the user to create projects, manage datasets, and capture data provenance while performing analysis tasks.

NOTE:
  `renga-python` is the python library for Renga that provides an SDK and a command-line interface (CLI). It does not start the Renga platform itself - for that, refer to the Renga docs on running the platform.

This is the development branch of `renga-python` and should be considered highly volatile. The documentation for certain components may be out of sync.

## Installation

The latest release is available on PyPI and can be installed using `pip`:

    $ pip install renga

The development branch can be installed directly from the Git repository:

    $ pip install -e git+https://github.com/SwissDataScienceCenter/renga-python.git@development#egg=renga

For more information about the Renga API see its documentation.

## Use the Renga command line

Interaction with the platform can take place via the command-line interface (CLI).

Start by creating for folder where you want to keep your Renga project:

    $ mkdir -p ~/temp/my-renga-project
    $ cd ~/temp/my-renga-project
    $ renga init

Create a dataset and add data to it:

    $ renga dataset create my-dataset
    $ renga dataset add my-dataset https://raw.githubusercontent.com/SwissDataScienceCenter/renga-python/development/README.rst

Run an analysis:

    $ renga run wc < data/my-dataset/README.rst > wc_readme

Trace the data provenance:

    $ renga log wc_readme

These are the basics, but there is much more that Renga allows you to do with your data analysis workflows.

For more information about using renga, refer to the Renga command line instructions.